#!/usr/bin/env python

from __future__ import absolute_import

from distutils.core import Command
from distutils.command.build_py import build_py as _build_py

import sys
import getpass
import distcontrib.api as api


class doctest(_build_py):

    description = 'Run doctests'

    def run(self):
        _build_py.run(self)
        api.doctests(self.distribution.packages).run()


class zap(Command):

    description = 'Remove all unneeded files and directories'

    user_options = [
        ('c-files',   'c', "(DANGEROUS) also delete '*.c,*.h' files"),
        ('cpp-files', 'p', "(DANGEROUS) also delete '*.cpp,*.hpp' files") ]
    boolean_options = ['c-files', 'cpp-files']
    help_options    = [ ]
    negative_opt    = { }
    sub_commands    = [ ]

    def initialize_options(self):
        self.c_files = False
        self.cpp_files = False
        self.verbose = False

    def finalize_options(self):
        self.zap = api.zap(self.c_files, self.cpp_files)
        self.zap.set_dry_run(self.dry_run)
        self.zap.set_verbose(self.verbose)

    def run(self):
        if not self.dry_run:
            self.zap.run()


class psql(Command):

    description = 'Runs psql'

    user_options = [
        ('createuser', None, "create user"),
        ('createdb',   None, "create database"),
        ('dropuser',   None, "drop user "),
        ('dropdb',     None, "drop database"),
        ('url=',        'u',  "database connection string. default: postgresql://" + getpass.getuser() + "@localhost:5432/sample"), ]

    boolean_options = [ 'createuser', 'createdb', 'dropuser', 'dropdb' ]
    help_options    = [ ]
    negative_opt    = { }
    sub_commands    = [ ]

    def initialize_options(self):
        self.createuser  = False
        self.createdb    = False
        self.dropuser    = False
        self.dropdb      = False
        self.url         = 'postgresql://' + getpass.getuser() + '@localhost:5432/sample'
        self.verbose     = False

    def finalize_options(self):
        self.psql = api.psql(self.url)
        self.psql.set_dry_run(self.dry_run)
        self.psql.set_verbose(self.verbose)

    def run(self):
        if not self.dry_run:
            self.psql.login()
            if self.dropdb or self.dropuser: self.psql.drop_db()
            if self.dropuser:                self.psql.drop_user()
            if self.createuser:              self.psql.create_user
            if self.createdb:                self.psql.create_db()


class migrate(Command):

    description = 'Runs sqlalchemy-migrate'

    user_options = [
        ('create-model',    None, "reverse engineer a database model"),
        ('upgrade',         None, "upgrades the database model (see: changeset)"),
        ('downgrade',       None, "downgrades the database model (see:changeset)"),
        ('test',            None, "performs upgrade+downgrade (see;changeset)"),
        ('status',          None, "database and repository status information"),

        #--
        ('repository=',  'r',  "migration repository. default: admin/migrate"),
        ('application=', 'a',  "application name"),
        ('url=',         'u',  "database connection string. default: postgresql://" + getpass.getuser() + "@localhost:5432/sample"),
        ('changeset=',   'c',  "apply a specific changeset version") ]

    boolean_options = ['create-model', 'upgrade', 'downgrade', 'test', 'status' ]
    help_options    = [ ]
    negative_opt    = { }
    sub_commands    = [ ]

    def initialize_options(self):
        self.create_model    = False
        self.upgrade         = False
        self.downgrade       = False
        self.test            = False
        self.status          = False
        #--
        self.application = self.distribution.get_name()
        self.repository  = 'admin/migrate'
        self.url         = 'postgresql://' + getpass.getuser() + '@localhost:5432/sample'
        self.changeset   = None
        self.verbose     = False

    def finalize_options(self):
        self.migrate = api.migrate(self.url,
                                   self.repository,
                                   self.application)
        self.migrate.set_dry_run(self.dry_run)
        self.migrate.set_verbose(self.verbose)

    def run(self):
        if not self.dry_run:
            if self.create_model: self.migrate.create_model()
            if self.upgrade:      self.migrate.upgrade(self.changeset)
            if self.downgrade:    self.migrate.downgrade(self.changeset)
            if self.test:         self.migrate.sanity()
            if self.status:       self.migrate.status()
