#!/usr/bin/env python

from setuptools import find_packages, setup
import distcontrib as p

import os
here = os.path.abspath(os.path.dirname(__file__))
try:
    README  = open(os.path.join(here, 'README.rst')).read()
    AUTHORS = open(os.path.join(here, 'AUTHORS.txt')).read()
    CHANGES = open(os.path.join(here, 'CHANGES.txt')).read()
except IOError:
    README = AUTHORS = CHANGES = ''

PACKAGE      = 'distcontrib'
VERSION      = '0.2.0'
DESCRIPTION  = 'Contributions to Distutils'
LICENSE      = 'OSI Approved :: BSD License'
URL          = 'http://' + PACKAGE + '.readthedocs.org/'
AUTHOR       = 'Richard Gomes http://rgomes-info.blogspot.com'
AUTHOR_EMAIL = 'rgomes.info@gmail.com'
KEYWORDS     = [ 'distribute','setuptools','pip','cython' ]
CLASSIFIERS  = [ 'License :: ' + LICENSE,
                 'Operating System :: OS Independent',
                 'Programming Language :: Python',
                 'Programming Language :: Cython',
                 'Development Status :: 3 - Alpha',
                 'Intended Audience :: Developers',
                 'Environment :: Console' ]

LONG_DESCRIPTION = README + AUTHOR + CHANGES
PACKAGES         = find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests"])

setup_requires = [ 'setuptools>=2.2',
                   'pip>=1.5',
                   'Cython',
                   ]

install_requires = [
                    'Tempita<0.53', 
                    'sqlalchemy-migrate',
                    ]

tests_require = [
                 'pytest',
                 'pytest-cov',
                 'pytest-pep8',
                 'pytest-xdist',
                 #'mock',
                 #'pyquery',
                 ]

docs_require = [
                'Sphinx',
                'docutils',
                'repoze.sphinx.autointerface',
                ]

extras_require={
                #'development': development_requires,
                'testing': tests_require,
                'docs': docs_require,
                }

setup(
    name=PACKAGE,
    version=VERSION,
    description=DESCRIPTION,
    url=URL,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    long_description=LONG_DESCRIPTION,
    license=LICENSE,
    keywords=KEYWORDS,
    classifiers=CLASSIFIERS,
    packages=PACKAGES,
    zip_safe=False,
    setup_requires=setup_requires,
    install_requires=install_requires,
    tests_require=tests_require,
    extras_require=extras_require,
    entry_points = {
        #-- 'console_scripts': [ ],
        #-- 'gui_scripts': [ ],
        'distutils.commands': [
            "zap = distcontrib.command:zap",
            "doctest = distcontrib.command:doctest",
            "psql = distcontrib.command:psql",
            "migrate = distcontrib.command:migrate",
        ],
#        'pytest11': [
#            'distcontrib = distcontrib.tests',
#        ],
    }
)
